<!--- app-name: Apache -->

# Chatbot-ui Module Chart

## TL;DR

## Introduction
Github: https://github.com/mckaywrigley/chatbot-ui/tree/main

## Prerequisites

- Kubernetes 1.19+
- Helm 3.2.0+

## Using the Chart

## Parameters

### Global parameters

| Name                            | Description                                                                                                 | Value                            |
| ------------------------------- | ----------------------------------------------------------------------------------------------------------- | -------------------------------- |
| `global.chartNameOverride`      | Overrides the chart name.                                                                                   | `""`                             |
| `global.releaseNameOverride`    | Overrides the release name.                                                                                 | `""`                             |
| `global.tags`                   | Define common tags for all IAC and app resources generated by this chart.                                   | `{}`                             |
| `global.labels`                 | Define common labels for all IAC and app resources generated by this chart.                                 | `{}`                             |
| `global.annotations`            | Define common annotations for all IAC and app resources generated by this chart.                            | `{}`                             |
| `global.awsAccountId`           | Default aws account id for crossplane aws provider resources. Quotes are important, value must be a string. | `0123456789`                     |
| `global.awsRegion`              | Default aws region for crossplane aws provider resources.                                                   | `us-east-2`                      |
| `global.providerConfigRef.name` | Default crossplane provider all resources generated for crossplane.                                         | `crossplane-provider-config-aws` |
| `global.secretStoreRef`         | External secrets secrets store ref                                                                          | `cluster-secret-store-aws`       |
| `global.environment`            | Application environment                                                                                     | `dev`                            |


### Chatbot UI configurations

| Name                                                                                                | Description                                                                                    | Value                                                                                                                          |
| --------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------ |
| `common-res.enabled`                                                                                | Toggle for enabling or disabling chatbot ui resources.                                         | `true`                                                                                                                         |
| `common-res.Deployment.items._.replicas`                                                            | Number of desired pods. Disable this if HPA is enabled                                         | `1`                                                                                                                            |
| `common-res.Deployment.items._.revisionHistoryLimit`                                                | ReplicaSet revision history limit                                                              | `3`                                                                                                                            |
| `common-res.Deployment.items._.strategy.type`                                                       | Set the controller upgrade strategy                                                            | `RollingUpdate`                                                                                                                |
| `common-res.Deployment.items._.strategy.rollingUpdate.maxUnavailable`                               | Set deployment RollingUpdate max unavailable                                                   | `66%`                                                                                                                          |
| `common-res.Deployment.items._.strategy.rollingUpdate.maxSurge`                                     | Set deployment RollingUpdate max surge                                                         | `33%`                                                                                                                          |
| `common-res.Deployment.items._.selector`                                                            | Additional selectors for the deployment                                                        | `{}`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.automountServiceAccountToken`                           | Automount Service account token                                                                | `false`                                                                                                                        |
| `common-res.Deployment.items._.podSpec.spec.restartPolicy`                                          | Restart policy for the pod                                                                     | `Always`                                                                                                                       |
| `common-res.Deployment.items._.podSpec.spec.securityContext.fsGroup`                                | Specify the default fs group id                                                                | `1000`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.securityContext.supplementalGroups`                     | Specify the additional groups                                                                  | `[]`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.securityContext.fsGroupChangePolicy`                    | Specify the default gs group change policy                                                     | `OnRootMismatch`                                                                                                               |
| `common-res.Deployment.items._.podSpec.spec.containers[0].name`                                     |                                                                                                | `chabot-ui`                                                                                                                    |
| `common-res.Deployment.items._.podSpec.spec.containers[0].image`                                    |                                                                                                | `ghcr.io/mckaywrigley/chatbot-ui:main`                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].imagePullPolicy`                          | Container image pullPolicy. Allowed values: `IfNotPresent`, `Always`, `Never`                  | `IfNotPresent`                                                                                                                 |
| `common-res.Deployment.items._.podSpec.spec.containers[0].tty`                                      | Determines whether containers in a pod runs with TTY enabled.                                  | `false`                                                                                                                        |
| `common-res.Deployment.items._.podSpec.spec.containers[0].stdin`                                    | Determines whether containers in a pod runs with stdin enabled.                                | `false`                                                                                                                        |
| `common-res.Deployment.items._.podSpec.spec.containers[0].ports[0].name`                            | Name of the port                                                                               | `http`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].ports[0].containerPort`                   | The port number                                                                                | `3000`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].ports[0].protocol`                        | Port protocol. Allowed values: "SCTP", `TCP` and `UDP`.                                        | `TCP`                                                                                                                          |
| `common-res.Deployment.items._.podSpec.spec.containers[0].livenessProbe.httpGet.port`               | Liveness probe port                                                                            | `3000`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].livenessProbe.httpGet.scheme`             | Liveness probe connection protocol                                                             | `HTTP`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].livenessProbe.httpGet.path`               | If a HTTP probe is used (default for HTTP/HTTPS services) this path is used                    | `/`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].livenessProbe.initialDelaySeconds`        | Initial delay in seconds                                                                       | `10`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.containers[0].livenessProbe.periodSeconds`              | period in seconds                                                                              | `10`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.containers[0].livenessProbe.timeoutSeconds`             | Timeout in seconds                                                                             | `5`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].livenessProbe.failureThreshold`           | max number of failures in a row for flagging pod as unhealthy                                  | `5`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].livenessProbe.successThreshold`           | max number of successes in a row for flagging pod as healthy                                   | `1`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].readinessProbe.httpGet.port`              | readiness probe port                                                                           | `3000`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].readinessProbe.httpGet.scheme`            | readiness probe connection protocol                                                            | `HTTP`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].readinessProbe.httpGet.path`              | If a HTTP probe is used (default for HTTP/HTTPS services) this path is used                    | `/`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].readinessProbe.initialDelaySeconds`       | Initial delay in seconds                                                                       | `10`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.containers[0].readinessProbe.periodSeconds`             | period in seconds                                                                              | `10`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.containers[0].readinessProbe.timeoutSeconds`            | Timeout in seconds                                                                             | `5`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].readinessProbe.failureThreshold`          | max number of failures in a row for flagging pod as not ready                                  | `5`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].readinessProbe.successThreshold`          | max number of successes in a row for flagging pod as ready                                     | `2`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].startupProbe.tcpSocket.port`              | startup probe port                                                                             | `3000`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].startupProbe.initialDelaySeconds`         | Initial delay in seconds                                                                       | `10`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.containers[0].startupProbe.periodSeconds`               | period in seconds                                                                              | `5`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].startupProbe.timeoutSeconds`              | Timeout in seconds                                                                             | `2`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].startupProbe.failureThreshold`            | max number of failures in a row for flagging pod as not started                                | `60`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.containers[0].startupProbe.successThreshold`            | max number of successes in a row for flagging pod as started                                   | `1`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].resources.limits.cpu`                     | CPU limits                                                                                     | `1`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].resources.limits.memory`                  | Memory limits                                                                                  | `512Mi`                                                                                                                        |
| `common-res.Deployment.items._.podSpec.spec.containers[0].resources.requests.cpu`                   | CPU requests                                                                                   | `1`                                                                                                                            |
| `common-res.Deployment.items._.podSpec.spec.containers[0].resources.requests.memory`                | Memory requests                                                                                | `512Mi`                                                                                                                        |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.runAsGroup`               | Specify the default user group id                                                              | `1000`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.runAsUser`                | Specify the default user id                                                                    | `1000`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.privileged`               | Privileged mode true or false. Allowed values: `true` or `false`                               | `false`                                                                                                                        |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.readOnlyRootFilesystem`   | Access level for the file system.  Allowed values: `true` or `false`                           | `true`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.allowPrivilegeEscalation` | Allow escalation of privileges true or false. Allowed values: `true` or `false`                | `false`                                                                                                                        |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.runAsNonRoot`             | Run the process as root, true or false. Allowed values: `true` or `false`                      | `true`                                                                                                                         |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.seccompProfile.type`      | Seccomp profile type                                                                           | `RuntimeDefault`                                                                                                               |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.capabilities.drop`        | Capabilities to drop                                                                           | `["ALL"]`                                                                                                                      |
| `common-res.Deployment.items._.podSpec.spec.containers[0].securityContext.capabilities.add`         | Capabilities to add                                                                            | `[]`                                                                                                                           |
| `common-res.Deployment.items._.podSpec.spec.containers[0].envFrom[0].configMapRef.name`             | ConfigMap name Ref                                                                             | `{{ include "common-gitops.names.release" . }}`                                                                                |
| `common-res.Deployment.items._.podSpec.spec.containers[0].envFrom[1].secretRef.name`                | Secret name Ref                                                                                | `{{ include "common-gitops.names.release" . }}`                                                                                |
| `common-res.ServiceAccount.items._.enabled`                                                         | Specifies whether a service account should be created. Allowed values: `true` or `false`       | `true`                                                                                                                         |
| `common-res.Secret.enabled`                                                                         | Enable or Disable the secret from being created. Allowed values: `true` or `false`             | `true`                                                                                                                         |
| `common-res.Secret.items._.stringData.OPENAI_API_KEY`                                               | OpenAI backend endpoint URL                                                                    | `YOUR_OPENAI_API_KEY`                                                                                                          |
| `common-res.Secret.items._.stringData.OPENAI_ORGANIZATION`                                          | OpenAI Org ID                                                                                  | `YOUR_OPENAI_ORGANIZATION_ID`                                                                                                  |
| `common-res.Secret.items._.stringData.AZURE_DEPLOYMENT_ID`                                          |                                                                                                | `""`                                                                                                                           |
| `common-res.Secret.items._.stringData.GOOGLE_API_KEY`                                               | Google API key                                                                                 | `""`                                                                                                                           |
| `common-res.Secret.items._.stringData.GOOGLE_CSE_ID`                                                | Google Search Engine ID                                                                        | `""`                                                                                                                           |
| `common-res.ConfigMap.enabled`                                                                      | Enable or Disable the configmap from being created. Allowed values: `true` or `false`          | `true`                                                                                                                         |
| `common-res.ConfigMap.items._.data.OPENAI_API_HOST`                                                 | OpenAI API Host                                                                                | `https://api.openai.com`                                                                                                       |
| `common-res.ConfigMap.items._.data.OPENAI_API_TYPE`                                                 | Allowed values: `openai` or `azure`                                                            | `openai`                                                                                                                       |
| `common-res.ConfigMap.items._.data.OPENAI_API_VERSION`                                              | OpenAI API Version for Azure deployment. Only applicable for Azure OpenAI                      | `""`                                                                                                                           |
| `common-res.ConfigMap.items._.data.DEFAULT_MODEL`                                                   | The default model to use on new conversations, for Azure use gpt-35-turbo                      | `gpt-3.5-turbo`                                                                                                                |
| `common-res.ConfigMap.items._.data.NEXT_PUBLIC_DEFAULT_SYSTEM_PROMPT`                               | OpenAI System prompt                                                                           | `You are ChatGPT, a large language model trained by OpenAI. Follow the user's instructions carefully. Respond using markdown.` |
| `common-res.ConfigMap.items._.data.NEXT_PUBLIC_DEFAULT_TEMPERATURE`                                 | The default temperature to use on new conversations                                            | `1`                                                                                                                            |
| `common-res.Service.items._.enabled`                                                                | Enables or disables the service                                                                | `true`                                                                                                                         |
| `common-res.Service.items._.spec.selector`                                                          | Additional selectors                                                                           | `{}`                                                                                                                           |
| `common-res.Service.items._.spec.type`                                                              | Set the service type                                                                           | `ClusterIP`                                                                                                                    |
| `common-res.Service.items._.spec.ipFamilyPolicy`                                                    | Specify the ip policy. Options: SingleStack, PreferDualStack, RequireDualStack                 | `SingleStack`                                                                                                                  |
| `common-res.Service.items._.spec.ports[0].name`                                                     | The port number                                                                                | `http`                                                                                                                         |
| `common-res.Service.items._.spec.ports[0].port`                                                     | The port number                                                                                | `3000`                                                                                                                         |
| `common-res.Service.items._.spec.ports[0].protocol`                                                 | Port protocol. Allowed values: `TCP`, `SCTP` or `UDP`.                                         | `TCP`                                                                                                                          |
| `common-res.Service.items._.spec.ports[0].targetPort`                                               | Specify a service targetPort if you wish to differ the service port from the application port. | `3000`                                                                                                                         |
| `common-res.Ingress.enabled`                                                                        | Enable or disable the ingress                                                                  | `true`                                                                                                                         |
| `common-res.Ingress.items._.annotations.kubernetes.io/ingress.allow-http`                           | Enable or disable non ssl connection on the ingress                                            | `false`                                                                                                                        |
| `common-res.Ingress.items._.annotations.nginx.ingress.kubernetes.io/backend-protocol`               | Backend protocol. Must match with backend service protocol                                     | `HTTP`                                                                                                                         |
| `common-res.Ingress.items._.annotations.nginx.ingress.kubernetes.io/preserve-trailing-slash`        | Enable or disable preservation of trailing slash                                               | `false`                                                                                                                        |
| `common-res.Ingress.items._.annotations.nginx.ingress.kubernetes.io/server-snippet`                 | Additional nginx configurations using server-snippet annotation                                | `proxy_ssl_verify off;
proxy_set_header X-Forwarded-Proto https;
`                                                             |
| `common-res.Ingress.items._.annotations.nginx.ingress.kubernetes.io/ssl-redirect`                   | Enable or disable redirecting users from non ssl to ssl URL                                    | `true`                                                                                                                         |
| `common-res.Ingress.items._.labels`                                                                 | Set labels on the deployment                                                                   | `{}`                                                                                                                           |
| `common-res.Ingress.items._.spec.ingressClassName`                                                  | Set the ingressClass that is used for this ingress.                                            | `""`                                                                                                                           |
| `common-res.Ingress.items._.spec.rules[0].host`                                                     | Host address. Helm template can be passed.                                                     | `chatbot-ui.dnsname.local`                                                                                                     |
| `common-res.Ingress.items._.spec.rules[0].http.paths[0].path`                                       | Path.  Helm template can be passed.                                                            | `/`                                                                                                                            |
| `common-res.Ingress.items._.spec.rules[0].http.paths[0].pathType`                                   | Ignored if not kubeVersion >= 1.14-0                                                           | `Prefix`                                                                                                                       |
| `common-res.Ingress.items._.spec.rules[0].http.paths[0].backend.service.name`                       | Overrides the service name reference for this path                                             | `{{ include "common-gitops.names.release" . }}`                                                                                |
| `common-res.Ingress.items._.spec.rules[0].http.paths[0].backend.service.port.number`                | Overrides the service port reference for this path                                             | `3000`                                                                                                                         |
| `common-res.Ingress.items._.spec.tls[0].secretName`                                                 | Name of the tls secret to use                                                                  | `tls-chatbot-ui.dnsname.local`                                                                                                 |
| `common-res.Ingress.items._.spec.tls[0].hosts`                                                      | List of virtual hosts to match                                                                 | `["chatbot-ui.dnsname.local"]`                                                                                                 |
| `common-res.HorizontalPodAutoscaler.enabled`                                                        | Toggle for enabling or disabling template.                                                     | `false`                                                                                                                        |
| `common-res.HorizontalPodAutoscaler.items._.spec.scaleTargetRef.apiVersion`                         | Target kind API Version                                                                        | `apps/v1`                                                                                                                      |
| `common-res.HorizontalPodAutoscaler.items._.spec.scaleTargetRef.kind`                               | Target kind                                                                                    | `Deployment`                                                                                                                   |
| `common-res.HorizontalPodAutoscaler.items._.spec.scaleTargetRef.name`                               | Target kind name                                                                               | `{{ include "common-gitops.names.release" . }}`                                                                                |
| `common-res.HorizontalPodAutoscaler.items._.spec.minReplicas`                                       | minimum amount of replica's to spawn                                                           | `1`                                                                                                                            |
| `common-res.HorizontalPodAutoscaler.items._.spec.maxReplicas`                                       | maximum amount of replica's to spawn                                                           | `10`                                                                                                                           |
| `common-res.HorizontalPodAutoscaler.items._.spec.metrics[0].type`                                   | Metrics type                                                                                   | `Resource`                                                                                                                     |
| `common-res.HorizontalPodAutoscaler.items._.spec.metrics[0].resource.name`                          | resource name of the metric                                                                    | `cpu`                                                                                                                          |
| `common-res.HorizontalPodAutoscaler.items._.spec.metrics[0].resource.target.type`                   | Metric target type for the resource                                                            | `Utilization`                                                                                                                  |
| `common-res.HorizontalPodAutoscaler.items._.spec.metrics[0].resource.target.averageUtilization`     | Average utilization value                                                                      | `80`                                                                                                                           |
| `common-res.HorizontalPodAutoscaler.items._.spec.metrics[1].type`                                   | Metrics type                                                                                   | `Resource`                                                                                                                     |
| `common-res.HorizontalPodAutoscaler.items._.spec.metrics[1].resource.name`                          | resource name of the metric                                                                    | `memory`                                                                                                                       |
| `common-res.HorizontalPodAutoscaler.items._.spec.metrics[1].resource.target.type`                   | Metric target type for the resource                                                            | `Utilization`                                                                                                                  |
| `common-res.HorizontalPodAutoscaler.items._.spec.metrics[1].resource.target.averageUtilization`     | Average utilization value                                                                      | `80`                                                                                                                           |


### Dependency: external-secrets upstream helm chart parameters for generating image pull secrets and other secrets for the app

| Name                                                                                       | Description                                                    | Value                                                                            |
| ------------------------------------------------------------------------------------------ | -------------------------------------------------------------- | -------------------------------------------------------------------------------- |
| `external-secrets.enabled`                                                                 | Toggle for enabling or disabling upstream chart templates.     | `false`                                                                          |
| `external-secrets.AWSExternalSecret.enabled`                                               | Toggle for enabling or disabling resource type.                | `true`                                                                           |
| `external-secrets.AWSExternalSecret.items._.name`                                          | Name of the secret to generate                                 | `{{ include "common-gitops.names.release" . }}`                                  |
| `external-secrets.AWSExternalSecret.items._.namespace`                                     | Target namespace for the generated secret                      | `{{ .Release.Namespace }}`                                                       |
| `external-secrets.AWSExternalSecret.items._.source.secretStoreRef.name`                    | Name of the external secretstore for AWS to fetch secrets data | `{{ .Values.global.secretStoreRef }}`                                            |
| `external-secrets.AWSExternalSecret.items._.source.data.OPENAI_API_KEY.awsSecretName`      | AWS Secrets manager secret name                                | `{{ .Values.global.environment }}-{{ include "common-gitops.names.release" . }}` |
| `external-secrets.AWSExternalSecret.items._.source.data.OPENAI_API_KEY.awsSecretKey`       | Data key inside the AWS Secrets manager secret                 | `OPENAI_API_KEY`                                                                 |
| `external-secrets.AWSExternalSecret.items._.source.data.OPENAI_ORGANIZATION.awsSecretName` | AWS Secrets manager secret name                                | `{{ .Values.global.environment }}-{{ include "common-gitops.names.release" . }}` |
| `external-secrets.AWSExternalSecret.items._.source.data.OPENAI_ORGANIZATION.awsSecretKey`  | Data key inside the AWS Secrets manager secret                 | `OPENAI_ORGANIZATION`                                                            |


### Dependency: crossplane-aws-secretsmanager upstream helm chart parameters for generating image pull secrets and other secrets for the app

| Name                                                                                   | Description                                                                                      | Value                                                                            |
| -------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------ | -------------------------------------------------------------------------------- |
| `crossplane-aws-secretsmanager.enabled`                                                | Toggle for enabling or disabling upstream chart templates.                                       | `false`                                                                          |
| `crossplane-aws-secretsmanager.Secret.items._.annotations.crossplane.io/external-name` | External name of the AWS Secret. Used for importing existing secret and avoid creating a new one | `{{ .Values.global.environment }}-{{ include "common-gitops.names.release" . }}` |
| `crossplane-aws-secretsmanager.Secret.items._.apiVersion`                              | Crossplane AWS provider apiVersion for AWS Secrets Secret object                                 | `secretsmanager.aws.upbound.io/v1beta1`                                          |
| `crossplane-aws-secretsmanager.Secret.items._.name`                                    | Name override for the secrets object visible to crossplane provider                              | `{{ .Values.global.environment }}-{{ include "common-gitops.names.release" . }}` |
| `crossplane-aws-secretsmanager.Secret.items._.forProvider.name`                        | Secret name in the AWS Secrets Manager                                                           | `{{ .Values.global.environment }}-{{ include "common-gitops.names.release" . }}` |
| `crossplane-aws-secretsmanager.Secret.items._.forProvider.description`                 | Secret description in the AWS Secrets Manager                                                    | `Chatbot UI Secrets`                                                             |


## Configuration and installation details


## Troubleshooting


## Notable changes
